@@ -4,7 +4,9 @@
 $rc = 0;
 
 ini_set('date.timezone', 'Europe/Zurich');
-ini_set('error_reporting', E_ALL & ~E_DEPRECATED);
+// ini_set('error_reporting', E_ALL & ~E_DEPRECATED);
+// We want to be more radical:
+ini_set('error_reporting', E_ALL);
 
 // Caution $_ENV variables are not be known here yet when variables_order
 // does NOT contain E!!!
@@ -179,7 +181,7 @@ fwrite($fh, "export MYSQL_TCP_PORT=" . $aDatabaseParameter['port'] . "\n");
 fwrite($fh, "export MYSQL_UNIX_PORT=" . $aDatabaseParameter['socket'] . "\n");
 fwrite($fh, "export MYENV_DATABASE=" . $lDbName . "\n");
 fwrite($fh, "export MYENV_DATADIR=" . $aDatabaseParameter['datadir'] . "\n");
-fwrite($fh, "export MYENV_VERSION=" . '1.0.4' . "\n");
+fwrite($fh, "export MYENV_VERSION=" . '1.0.5' . "\n");
 fwrite($fh, "export MYSQL_PS1='\u@\h " . $lDbName . " [\d] SQL> '\n");
 
 // Add user export variables here
