@@ -68,8 +68,10 @@ print "\n";
 
 // Display up and down instances
 
-$aUp   = array();
-$aDown = array();
+$aUp      = array();
+$aDown    = array();
+$aPassive = array();   // For passive databases on an active/passive fail-over cluster
+
 foreach ( $aDbNames as $db ) {
 
   if ( count($aConfiguration[$db]) == 0 ) {
@@ -78,24 +80,40 @@ foreach ( $aDbNames as $db ) {
     continue;
   }
 
-  $ret = checkDatabase($aConfiguration[$db]);
+	// Ignore passive databases in an active/passive fail-over Cluster
+	// Criteria is that datadir is missing!
+	if ( isset($aConfiguration[$db]['ignore-passive'])
+	  && ($aConfiguration[$db]['ignore-passive'] == 'yes')
+		&& ( ! is_dir($aConfiguration[$db]['datadir']))
+	  ) {
+		$aPassive[$db] = "$db (" . $aConfiguration[$db]['version'] . ")";
+	}
+	// Database is NOT passive so check if it is up or down.
+	else {
 
-  if ( $ret != 0 ) {
-    $aDown[$db] = "$db (" . $aConfiguration[$db]['version'] . ")";
-  }
-  else {
-    $aUp[$db]   = "$db (" . $aConfiguration[$db]['version'] . ")";
-  }
+		$ret = checkDatabase($aConfiguration[$db]);
+
+		if ( $ret != 0 ) {
+			$aDown[$db] = "$db (" . $aConfiguration[$db]['version'] . ")";
+		}
+		else {
+			$aUp[$db]   = "$db (" . $aConfiguration[$db]['version'] . ")";
+		}
+	}
 }
 
 if ( $lDebug != '' ) {
-  var_dump($aUp);
-  var_dump($aDown);
+	print 'Up  : ';
+	var_dump($aUp);
+	print 'Down: ';
+	var_dump($aDown);
+	print 'Passive: ';
+	var_dump($aPassive);
 }
 
 // Print Up line
 $cnt = 1;
-foreach ( split("\n", wordwrap(implode(' ', $aUp), $lNumberOfColumns-12)) as $line ) {
+foreach ( explode("\n", wordwrap(implode(' ', $aUp), $lNumberOfColumns-12)) as $line ) {
 
   if ( $cnt == 1 ) {
     print "Up       : " . $line . "\n";
@@ -109,7 +127,7 @@ print "\n";
 
 // Print Down line
 $cnt = 1;
-foreach ( split("\n", wordwrap(implode(' ', $aDown), $lNumberOfColumns-12)) as $line ) {
+foreach ( explode("\n", wordwrap(implode(' ', $aDown), $lNumberOfColumns-12)) as $line ) {
 
   if ( $cnt == 1 ) {
     print "Down     : " . $line . "\n";
@@ -121,20 +139,62 @@ foreach ( split("\n", wordwrap(implode(' ', $aDown), $lNumberOfColumns-12)) as $
 }
 print "\n";
 
+// Print Passive line only if some are there
+if ( count($aPassive) > 0 ) {
+	$cnt = 1;
+	foreach ( explode("\n", wordwrap(implode(' ', $aPassive), $lNumberOfColumns-12)) as $line ) {
+
+		if ( $cnt == 1 ) {
+			print "Passive  : " . $line . "\n";
+		}
+		else {
+			print "           " . $line . "\n";
+		}
+		$cnt++;
+	}
+	print "\n";
+}
+
+// Find the longes instance name
+$max_len = max(array_map('strlen', $aDbNames));
+
+// Print all instances
 foreach ( $aDbNames as $db ) {
 
-  $aSchema = getSchemaNames($aConfiguration[$db]['datadir']);
-  $tohide = '';
+	$aSchema = getSchemaNames($aConfiguration[$db]['datadir']);
+	$tohide = '';
 
-  // hide schema, e.g mysql, ndbinfo, test, performance_schema, pbxt
-  if ( array_key_exists('hideschema', $aConfiguration[$db]) ) {
+	// hide schema, e.g mysql, ndbinfo, test, performance_schema, pbxt
+	if ( array_key_exists('hideschema', $aConfiguration[$db]) ) {
 
-    foreach ( explode(',', $aConfiguration[$db]['hideschema']) as $tohide ) {
-      unset($aSchema[array_search($tohide, $aSchema)]);
-    }
-  }
+		foreach ( explode(',', $aConfiguration[$db]['hideschema']) as $tohide ) {
+			unset($aSchema[array_search($tohide, $aSchema)]);
+		}
+	}
 
-  printf("%-24s (%5d) : %s\n", $db, $aConfiguration[$db]['port'], implode(' ', $aSchema));
+	// Ignore passive databases in an active/passive fail-over Cluster
+	// Criteria is that datadir is missing!
+	if ( isset($aConfiguration[$db]['ignore-passive'])
+	  && ($aConfiguration[$db]['ignore-passive'] == 'yes')
+		&& ( ! is_dir($aConfiguration[$db]['datadir']))
+	  ) {
+	  // noop
+	}
+	else {
+		// Split the schema output
+		$cnt = 1;
+		
+		foreach ( explode("\n", wordwrap(implode(' ', $aSchema), $lNumberOfColumns-$max_len-13)) as $line ) {
+
+			if ( $cnt == 1 ) {
+				printf("%-" . $max_len . "s (%5d) : %s\n", $db, $aConfiguration[$db]['port'], $line);
+			}
+			else {
+				printf("%s %s\n", str_repeat(' ', $max_len+10), $line);
+			}
+			$cnt++;
+		}
+	}
 }
 print "\n";
 
