@@ -37,7 +37,7 @@ if ( count($argv) != count($aOptions) ) {
   exit($rc);
 }
 
-$ret = &checkArguments($aOptions);
+$ret = checkArguments($aOptions);
 if ( $ret != 0 ) {
   $rc = 27;
   printUsage();
@@ -45,7 +45,7 @@ if ( $ret != 0 ) {
 }
 
 // ---------------------------------------------------------------------
-function checkArguments(&$aOptions)
+function checkArguments($aOptions)
 // ---------------------------------------------------------------------
 {
   $ret = 0;
